package org.openscm.kundo.factory

/*
 * Copyright (C) 2008 The Ultimate People Company Ltd ("UPCO").
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.openscm.kundo.common.logging.SimpleLogger

/**
 * Abstract Dependencies Factory
 * @author <a href="mailto:ben.leedham@upco.co.uk">Ben Leedham</a>
 * @version 1.0.0
 * 
 * Description: The AbstractDependenciesFactory sets and holds generic Dependency Factory data 
 * 
 */
public abstract class AbstractDependenciesFactory{
	
	/** AntBuilder instance. **/
	protected AntBuilder ant
	
	/** Logger instance. **/
	final SimpleLogger log
	
	/** Strategy to use **/
	protected strategy
	
	/** The current projects base directory **/
	protected basedir	
	
	/**
	 * Constructor sets ant instance
	 * @param ant			AntBuilder instance
	 */
	 AbstractDependenciesFactory( AntBuilder ant ){
		this.ant = ant
		this.log = SimpleLogger.getInstance( ant )
		this.basedir = ant.project.getProperty( "basedir" )
	}
	
	/**
	 * Setter method for member variable strategy
	 * @param method	String representation of the strategy to use
	 */	
	void setStrategy( String strategy ){
		this.strategy = strategy
	}	

}
