package org.openscm.kundo.factory

/*
 * Copyright (C) 2008 The Ultimate People Company Ltd ("UPCO").
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.apache.tools.ant.BuildException
import org.openscm.kundo.plugins.context.BuildContext
import org.openscm.kundo.common.logging.SimpleLogger
import org.openscm.kundo.strategy.CopyDependenciesStrategy
import org.openscm.kundo.strategy.DefaultCopyDependenciesStrategy
//import org.openscm.kundo.strategy.EclipseLoadDependenciesStrategy

/**
 * Copy Dependencies Factory
 * @author <a href="mailto:ben.leedham@upco.co.uk">Ben Leedham</a>
 * @version 1.0.0
 * 
 * Description: The CopyDependenciesFactory identifies and returns an appropriate CopyDependenciesStrategy based on the build context. 
 * 
 * <p>The CopyDependenciesFactory identifies an appropriate CopyDependenciesStrategy from from data within the BuildContext. 
 * If a pom file is available in the build context pom.location property then a MavenCopyDependenciesStrategy will be returned. 
 * If no strategy can be identified then an Exception will be thrown</p>
 */
public class CopyDependenciesFactory extends AbstractDependenciesFactory{
	
	/**
	 * Constructor sets ant instance
	 * @param ant			AntBuilder instance
	 */
	 CopyDependenciesFactory( AntBuilder ant ){
		super( ant )
	}

	/**
	 * Identifies and returns an appropriate CopyDependenciesStrategy for the current state. 
	 * @param buildContext	The current BuildContext instance containing the global ant project.
	 * @return CopyDependenciesStrategy	Instance of the appropriate CopyDependenciesStrategy for the current build context data.
	 */
	 CopyDependenciesStrategy getCopyDependenciesStrategy( BuildContext buildContext ) {

		// ---------------------------------------------------
		// Default Strategy
		// ---------------------------------------------------		

		log.debug( 'Creating Default Copy Dependencies Strategy' )

		CopyDependenciesStrategy mcds = new DefaultCopyDependenciesStrategy( ant, buildContext )
		return mcds
		
		// ---------------------------------------------------
		//	Add other strategies here as they are developed... 
		// ---------------------------------------------------
		
		// .........
		
		throw new BuildException( "No relevant CopyDependenciesStrategy could be found, please check your recipe and properties files to verify your config" )
	}
}
