package org.openscm.kundo.factory

/*
 * Copyright (C) 2008 The Ultimate People Company Ltd ("UPCO").
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.apache.tools.ant.BuildException
import org.openscm.kundo.plugins.context.BuildContext
import org.openscm.kundo.common.logging.SimpleLogger
import org.openscm.kundo.strategy.InstallDeployStrategy
import org.openscm.kundo.strategy.MavenInstallDeployStrategy
//import org.openscm.kundo.strategy.EclipseLoadDependenciesStrategy

/**
 * InstallDeployFactory
 * @author <a href="mailto:ben.leedham@upco.co.uk">Ben Leedham</a>
 * @version 1.0.0
 * 
 * Description: The InstallDeployFactory identifies and returns an appropriate InstallDeployStrategy based on the build context. 
 * 
 * <p>The InstallDeployFactory identifies an appropriate InstallDeployStrategy from from data within the BuildContext. 
 * If a pom file is available in the build context pom.location property then a MavenInstallDeployStrategy will be returned. 
 * Currently Maven is teh only strategy supported for installation and deployment of artifacts to repositories</p>
 */
public class InstallDeployFactory extends AbstractDependenciesFactory{

	/**
	 * Constructor sets ant instance
	 * @param ant			AntBuilder instance
	 */
	 InstallDeployFactory( AntBuilder ant ){
		super( ant )
	}

	/**
	 * Identifies and returns an appropriate InstallDeployStrategy for the current state. 
	 * @param buildContext	The current BuildContext instance containing the global ant project.
	 * @return InstallDeployStrategy	Instance of the appropriate InstallDeployStrategy for the current build context data.
	 */
	 InstallDeployStrategy getInstallDeployStrategy( BuildContext buildContext ) {

		// ---------------------------------------------------
		// Maven Strategy
		// ---------------------------------------------------		
		// Check to see if the pom file exists by retrieving and loading it from the build context.
		if( strategy.equals( "maven" ) && buildContext.isSet( "pom.location" ) ) {
			def pom = buildContext.get( "pom.location" )
			log.debug( 'Creating Maven Install Deploy Strategy' )
			File file = new File( pom )
			if ( file.exists() ) {
				InstallDeployStrategy mids = new MavenInstallDeployStrategy( ant, buildContext )
				return mids
			}
		}
		
		// ---------------------------------------------------
		//	Add other strategies here as they are developed... 
		// ---------------------------------------------------
		
		// .........
		
		// ---------------------------------------------------
		// Eclipse Strategy		
		// ---------------------------------------------------

		// Last one in the list. Will always fall into this as an empty property is declared
		// in the plugin.properties file.
		/*def moduleString = ant.project.properties.'reactor.module.list'
		if( moduleString != null ) {
			log.debug( 'Creating Eclipse Load Dependencies Strategy' )
			LoadDependenciesStrategy elds = new EclipseLoadDependenciesStrategy( ant )
			return elds
		}*/
		
		throw new BuildException( "No pom location could be found please check your pom location settings" )		
	}
}
