package org.openscm.kundo.plugins

/*
 * Copyright (C) 2008 The Ultimate People Company Ltd ("UPCO").
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 import org.openscm.kundo.plugins.context.BuildContext
 import org.openscm.kundo.factory.CopyDependenciesFactory
 import org.openscm.kundo.strategy.CopyDependenciesStrategy
 
 /**
  * Copy Dependencies Delegate
  * @author <a href="mailto:ben.leedham@upco.co.uk">Ben Leedham</a>
  * @version 1.0.0
  * 
  * Description: The CopyDependenciesDelegate loads indexed properties from either
  * build.properties, the default plugin.properties or another properties file specified
  * in build.properties. It the selects the appropriate CopyDependenciesStrategy to use
  * for the current build using the CopyDependenciesFactory current supported strategies are:
  * Maven POM dependencies
  * Eclipse .classpath Dependencies
  */ 
 
 public class CopyDependenciesDelegate extends AbstractPluginTargetDelegate{
	  
	/**
	 * Constructor
	 * @param ant			AntBuilder instance
	 * @param buildContext	BuildContext instance
	 */	  
	  CopyDependenciesDelegate( AntBuilder ant, BuildContext buildContext ){
		  super( ant, buildContext )
	  }
	  
	/*
	 * whether to flatten the directory structure of teh files to be copied
	 * @ant-property-name dependency-management.copy.flatten
	 */	
	 String copyFlatten	
	 
	/*
	 * A set of scopes and destination directories for dependencies to be copied to. Format: [plugin].[key].[index].[fieldname]
	 * @indexed-ant-property indexed
	 */	
	Map indexedProps
	
	/**
	 * Setter method for member variable copyFlatten
	 * @param copyFlatten	String representation of whether to flatten directory structure of files being copied
	 */	
	void setCopyFlatten( String copyFlatten ){
		this.copyFlatten = copyFlatten
	}	
	
	/**
	 * Setter method for member variable indexedProps
	 * @param indexedProps	Map of aggregated properties objects containing scope and destination info.
	 */	
	void setIndexedProps( Map indexedProps ){
		this.indexedProps = indexedProps
	}		  

	/**
	 * Implementation of abstract method from AbstractPluginTargetDelegate
	 * to hold assertions that all global and local properties are available to the plugin.
	 * This method is automatically called prior to execution.
	 */	
	void doCheck(){
		assert buildContext.isSet( "helper.strategy" )
	}
	
	/**
	 * Concrete implementation of the AbstractPluginTargetDelegate.execute() method
	 */	
	void doExecute(){
		def strategy = buildContext.get( "helper.strategy" )
		log.debug( "Helper strategy in use $strategy" )
		CopyDependenciesFactory cdf = new CopyDependenciesFactory( ant )
		cdf.setStrategy( strategy )
		CopyDependenciesStrategy cds = cdf.getCopyDependenciesStrategy( buildContext )
		cds.setIndexedProps( this.indexedProps )
		cds.setCopyFlatten( this.copyFlatten )
		cds.doExecute()
	}
	 
 }