package org.openscm.kundo.plugins

/*
 * Copyright (C) 2008 The Ultimate People Company Ltd ("UPCO").
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 import org.openscm.kundo.plugins.context.BuildContext
 import org.openscm.kundo.factory.InstallDeployFactory
 import org.openscm.kundo.strategy.InstallDeployStrategy
 
 /**
  * Install Deploy Delegate
  * @author <a href="mailto:ben.leedham@upco.co.uk">Ben Leedham</a>
  * @version 1.0.0
  * 
  * Description: The InstallDeployDelegate loads the method to use (Install, Deploy)
  * based on the target called, it loads the type of file to Install/Deploy either 
  * artifact or POM (Maven specific), it then uses the InstallDeployFactory to select
  * the appropriate InstallDeployStrategy to use for the current build. Current supported
  * strategies are:
  * Maven 
  */ 
 
 public class InstallDeployDelegate extends AbstractPluginTargetDelegate{
	  
	/**
	 * Constructor
	 * @param ant			AntBuilder instance
	 * @param buildContext	BuildContext instance
	 */	
	InstallDeployDelegate( AntBuilder ant, BuildContext buildContext ){
		super( ant, buildContext )
	}
	  
	/*
	 * A property to decide if install or deploy should be used
	 */
	protected String method
	
	/*
	 * A property to decide what should be installed artifact or pom
	 */
	protected String type
	
	/**
	 * Setter method for member variable method
	 * @param method	String representation of the method to use install/deploy
	 */	
	void setMethod( String method ){
		this.method = method
	}
	
	/**
	 * Setter method for member variable type
	 * @param type	String representation of the artifact type pom/artifact
	 */	
	void setType( String type ){
		this.type = type
	}	  

	/**
	 * Implementation of abstract method from AbstractPluginTargetDelegate
	 * to hold assertions that all global and local properties are available to the plugin.
	 * This method is automatically called prior to execution.
	 */
	void doCheck(){
		assert buildContext.isSet( "helper.strategy" )
	}
	
	/**
	 * Concrete implementation of the AbstractPluginTargetDelegate.execute() method
	 */	
	void doExecute(){
		def strategy = buildContext.get( "helper.strategy" )
		log.debug( "Helper strategy in use $strategy" )
		InstallDeployFactory idf = new InstallDeployFactory( ant )
		idf.setStrategy( strategy )
		InstallDeployStrategy ids = idf.getInstallDeployStrategy( buildContext )
		ids.setMethod( this.method )
		ids.setType( this.type )
		ids.doExecute()		  
	}
	 
 }